# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`cvmfs`](#cvmfs): Installs and Configures CvmFS

#### Private Classes

* `cvmfs::apt`: Configure cvmfs apt repositories
* `cvmfs::config`: Central configuration of CvmFS
* `cvmfs::fsck`: enable check_fsck as a cron or systemd timer
* `cvmfs::install`: Install cvmfs from a yum repository.
* `cvmfs::service`: Manages the cvmfs services. Opionally this also manages the autofs services
* `cvmfs::yum`: Configure cvmfs yum repositories

### Defined types

* [`cvmfs::domain`](#cvmfs--domain): Configure a a domain of cvmfs repositories
* [`cvmfs::id_map`](#cvmfs--id_map): Create a map file uid or gid mappings
* [`cvmfs::mount`](#cvmfs--mount): Mount one cvmfs repository. Most parameters map as lower case
versions of the raw cvmfs parameters.

## Classes

### <a name="cvmfs"></a>`cvmfs`

Deprecated paramters below

* **See also**
  * https://cvmfs.readthedocs.io/en/stable/apx-parameters.html
    * CVMFS configuration parameters

#### Examples

##### Simple Example For one Mount

```puppet
class{'cvmfs':
  cvmfs_http_proxy => 'http://ca-proxy.example.org:3128',
  cvmfs_quota_limit => 100
}
cvmfs::mount{'files.example.org:
  cvmfs_server_url => 'http://web.example.org/cvmfs/files.example.org',
}
```

##### Mount a Domain

```puppet
class{'cvmfs':
  cvmfs_http_proxy  => 'http://ca-proxy.example.org:3128',
  cvmfs_quota_limit => 100,
}
cvmfs::domain{'example.net'
  cvmfs_server_url => 'http://web.example.org/cvmfs/@fqrn@'
}
```

##### Use fuse3 version of cvmfs

```puppet
class{'cvmfs':
  fuse3 => true,
}
```

##### Use Mount rather than AutoFS

```puppet
class{'cvmfs':
  mount_method => 'mount',
}
```

##### Specify mounts as a hash

```puppet
class{'cvmfs':
  cvmfs_hash => {
    'foo.example.org' => { 'cvmfs_server_url => 'http://web.example.org/cmfs/foo.example.org' },
    'bar.example.org' => { 'cvmfs_server_url => 'http://web.example.org/cvmfs/bar.example.org' },
  }
}
```

##### New parameters with CvmFS 2.11.0

```puppet
class{'cvmfs':
  cvmfs_cache_symlinks => 'yes',
  cvmfs_streaming_cache => 'no',
  cvmfs_statfs_cache_timeout => 10,
  cvmfs_world_readable => 'yes',
  cvmfs_cpu_affinity => [0,1,2],
  cvmfs_xattr_privileged_gids => [100,101,102],
  cvmfs_xattr_protected_xattrs => ['user.foo','user.bar'],
  cvmfs_cache_refcount => 'yes',
}
```

#### Parameters

The following parameters are available in the `cvmfs` class:

* [`mount_method`](#-cvmfs--mount_method)
* [`manage_autofs_service`](#-cvmfs--manage_autofs_service)
* [`cvmfs_quota_limit`](#-cvmfs--cvmfs_quota_limit)
* [`cvmfs_quota_ratio`](#-cvmfs--cvmfs_quota_ratio)
* [`cvmfs_http_proxy`](#-cvmfs--cvmfs_http_proxy)
* [`cvmfs_cache_base`](#-cvmfs--cvmfs_cache_base)
* [`cvmfs_cache_owner`](#-cvmfs--cvmfs_cache_owner)
* [`cvmfs_cache_group`](#-cvmfs--cvmfs_cache_group)
* [`cvmfs_cache_mode`](#-cvmfs--cvmfs_cache_mode)
* [`cvmfs_ipfamily_prefer`](#-cvmfs--cvmfs_ipfamily_prefer)
* [`cvmfs_dns_min_ttl`](#-cvmfs--cvmfs_dns_min_ttl)
* [`cvmfs_dns_max_ttl`](#-cvmfs--cvmfs_dns_max_ttl)
* [`cvmfs_claim_ownership`](#-cvmfs--cvmfs_claim_ownership)
* [`cvmfs_uid_map`](#-cvmfs--cvmfs_uid_map)
* [`cvmfs_gid_map`](#-cvmfs--cvmfs_gid_map)
* [`cvmfs_memcache_size`](#-cvmfs--cvmfs_memcache_size)
* [`cvmfs_mount_rw`](#-cvmfs--cvmfs_mount_rw)
* [`cvmfs_follow_redirects`](#-cvmfs--cvmfs_follow_redirects)
* [`cvmfs_timeout`](#-cvmfs--cvmfs_timeout)
* [`cvmfs_timeout_direct`](#-cvmfs--cvmfs_timeout_direct)
* [`cvmfs_nfiles`](#-cvmfs--cvmfs_nfiles)
* [`cvmfs_syslog_level`](#-cvmfs--cvmfs_syslog_level)
* [`cvmfs_tracefile`](#-cvmfs--cvmfs_tracefile)
* [`cvmfs_debuglog`](#-cvmfs--cvmfs_debuglog)
* [`cvmfs_max_ttl`](#-cvmfs--cvmfs_max_ttl)
* [`cvmfs_version`](#-cvmfs--cvmfs_version)
* [`repo_base`](#-cvmfs--repo_base)
* [`repo_includepkgs`](#-cvmfs--repo_includepkgs)
* [`repo_priority`](#-cvmfs--repo_priority)
* [`repo_proxy`](#-cvmfs--repo_proxy)
* [`repo_config_enabled`](#-cvmfs--repo_config_enabled)
* [`repo_testing_enabled`](#-cvmfs--repo_testing_enabled)
* [`repo_gpgcheck`](#-cvmfs--repo_gpgcheck)
* [`repo_gpgkey`](#-cvmfs--repo_gpgkey)
* [`repo_manage`](#-cvmfs--repo_manage)
* [`cvmfs_use_geoapi`](#-cvmfs--cvmfs_use_geoapi)
* [`cvmfs_repositories`](#-cvmfs--cvmfs_repositories)
* [`cvmfs_hash`](#-cvmfs--cvmfs_hash)
* [`cvmfs_env_variables`](#-cvmfs--cvmfs_env_variables)
* [`default_cvmfs_partsize`](#-cvmfs--default_cvmfs_partsize)
* [`cvmfs_domain_hash`](#-cvmfs--cvmfs_domain_hash)
* [`cvmfs_instrument_fuse`](#-cvmfs--cvmfs_instrument_fuse)
* [`cvmfs_repo_list`](#-cvmfs--cvmfs_repo_list)
* [`cvmfs_alien_cache`](#-cvmfs--cvmfs_alien_cache)
* [`cvmfs_shared_cache`](#-cvmfs--cvmfs_shared_cache)
* [`cvmfs_fsck`](#-cvmfs--cvmfs_fsck)
* [`cvmfs_fsck_options`](#-cvmfs--cvmfs_fsck_options)
* [`cvmfs_fsck_onreboot`](#-cvmfs--cvmfs_fsck_onreboot)
* [`fuse3`](#-cvmfs--fuse3)
* [`cvmfs_cache_symlinks`](#-cvmfs--cvmfs_cache_symlinks)
* [`cvmfs_streaming_cache`](#-cvmfs--cvmfs_streaming_cache)
* [`cvmfs_statfs_cache_timeout`](#-cvmfs--cvmfs_statfs_cache_timeout)
* [`cvmfs_world_readable`](#-cvmfs--cvmfs_world_readable)
* [`cvmfs_cpu_affinity`](#-cvmfs--cvmfs_cpu_affinity)
* [`cvmfs_xattr_privileged_gids`](#-cvmfs--cvmfs_xattr_privileged_gids)
* [`cvmfs_xattr_protected_xattrs`](#-cvmfs--cvmfs_xattr_protected_xattrs)
* [`cvmfs_cache_refcount`](#-cvmfs--cvmfs_cache_refcount)
* [`cvmfs_yum`](#-cvmfs--cvmfs_yum)
* [`cvmfs_yum_priority`](#-cvmfs--cvmfs_yum_priority)
* [`cvmfs_yum_proxy`](#-cvmfs--cvmfs_yum_proxy)
* [`cvmfs_yum_config`](#-cvmfs--cvmfs_yum_config)
* [`cvmfs_yum_config_enabled`](#-cvmfs--cvmfs_yum_config_enabled)
* [`cvmfs_yum_testing`](#-cvmfs--cvmfs_yum_testing)
* [`cvmfs_yum_testing_enabled`](#-cvmfs--cvmfs_yum_testing_enabled)
* [`cvmfs_yum_gpgcheck`](#-cvmfs--cvmfs_yum_gpgcheck)
* [`cvmfs_yum_gpgkey`](#-cvmfs--cvmfs_yum_gpgkey)
* [`cvmfs_yum_manage_repo`](#-cvmfs--cvmfs_yum_manage_repo)
* [`cvmfs_yum_includepkgs`](#-cvmfs--cvmfs_yum_includepkgs)

##### <a name="-cvmfs--mount_method"></a>`mount_method`

Data type: `Enum['autofs','mount','none']`

The `autofs` option will configure cvmfs to be mounted with autofs. The `mount` option will
use puppet's mount type, currently adding a line to /etc/fstab. The *none* option
skips all mounting.  Note that migrating between for instance *autofs* and then *mount* is not supported.

Default value: `'autofs'`

##### <a name="-cvmfs--manage_autofs_service"></a>`manage_autofs_service`

Data type: `Boolean`

should the autofs service be maintained.

Default value: `true`

##### <a name="-cvmfs--cvmfs_quota_limit"></a>`cvmfs_quota_limit`

Data type: `Variant[Enum['auto'],Integer]`

The cvmfs quota size in megabytes.

Default value: `1000`

##### <a name="-cvmfs--cvmfs_quota_ratio"></a>`cvmfs_quota_ratio`

Data type: `Float`

If set , e.g '0.8', then 0.8 of the partition size
the cvmfs cache is on will be used. Setting this assumes you have
pre-allocated a partition to the cvmfs cache or else it makes little sense.

Default value: `0.85`

##### <a name="-cvmfs--cvmfs_http_proxy"></a>`cvmfs_http_proxy`

Data type: `Variant[Undef,String]`

List of squid servers, e.g `http://squid1.example.org;http;//squid2.example.org`

##### <a name="-cvmfs--cvmfs_cache_base"></a>`cvmfs_cache_base`

Data type: `Stdlib::Absolutepath`

Location of the CVMFS cache base

Default value: `'/var/lib/cvmfs'`

##### <a name="-cvmfs--cvmfs_cache_owner"></a>`cvmfs_cache_owner`

Data type: `String[1]`

expected owner of cvmfs cache

Default value: `'cvmfs'`

##### <a name="-cvmfs--cvmfs_cache_group"></a>`cvmfs_cache_group`

Data type: `String[1]`

expected group of cvmfs cache

Default value: `'cvmfs'`

##### <a name="-cvmfs--cvmfs_cache_mode"></a>`cvmfs_cache_mode`

Data type: `Stdlib::Filemode`

expected mode of cvmfs cache

Default value: `'0700'`

##### <a name="-cvmfs--cvmfs_ipfamily_prefer"></a>`cvmfs_ipfamily_prefer`

Data type: `Optional[Variant[Integer[4,4],Integer[6,6]]]`

Preferred IP protocol for dual-stack proxies. If not set, cvmfs default will be used.

Default value: `undef`

##### <a name="-cvmfs--cvmfs_dns_min_ttl"></a>`cvmfs_dns_min_ttl`

Data type: `Optional[Integer]`

Minimum ttl of DNS lookups in seconds.

Default value: `undef`

##### <a name="-cvmfs--cvmfs_dns_max_ttl"></a>`cvmfs_dns_max_ttl`

Data type: `Optional[Integer]`

Maximum ttl of DNS lookups in seconds.

Default value: `undef`

##### <a name="-cvmfs--cvmfs_claim_ownership"></a>`cvmfs_claim_ownership`

Data type: `Optional[Enum['yes','no']]`

Whether the client claims ownership of files or not.

Default value: `undef`

##### <a name="-cvmfs--cvmfs_uid_map"></a>`cvmfs_uid_map`

Data type: `Optional[Hash[Variant[Integer,String], Integer, 1]]`

Hash of UID pairs to map UIDs from catalogue to on the client.

Default value: `undef`

##### <a name="-cvmfs--cvmfs_gid_map"></a>`cvmfs_gid_map`

Data type: `Optional[Hash[Variant[Integer,String], Integer, 1]]`

Hash of GID pairs to map GIDs from catalogue to on the client.

Default value: `undef`

##### <a name="-cvmfs--cvmfs_memcache_size"></a>`cvmfs_memcache_size`

Data type: `Optional[Integer]`

Size of the CernVM-FS meta-data memory cache in Megabyte.

Default value: `undef`

##### <a name="-cvmfs--cvmfs_mount_rw"></a>`cvmfs_mount_rw`

Data type: `Optional[Enum['yes','no']]`

Mount option to mount as read-only or read/write.

Default value: `undef`

##### <a name="-cvmfs--cvmfs_follow_redirects"></a>`cvmfs_follow_redirects`

Data type: `Optional[Enum['yes','no']]`

Sets CVMFS_FOLLOW_REDIRECTS to its value

Default value: `undef`

##### <a name="-cvmfs--cvmfs_timeout"></a>`cvmfs_timeout`

Data type: `Optional[Integer]`

cvmfs timeout setting.

Default value: `undef`

##### <a name="-cvmfs--cvmfs_timeout_direct"></a>`cvmfs_timeout_direct`

Data type: `Optional[Integer]`

cvmfs timeout to direct connections.

Default value: `undef`

##### <a name="-cvmfs--cvmfs_nfiles"></a>`cvmfs_nfiles`

Data type: `Optional[Integer]`

Number of open files, system setting.

Default value: `undef`

##### <a name="-cvmfs--cvmfs_syslog_level"></a>`cvmfs_syslog_level`

Data type: `Optional[Integer[1,2]]`

Level to syslog at.

Default value: `undef`

##### <a name="-cvmfs--cvmfs_tracefile"></a>`cvmfs_tracefile`

Data type: `Optional[Stdlib::Absolutepath]`

Create a tracefile at this location.

Default value: `undef`

##### <a name="-cvmfs--cvmfs_debuglog"></a>`cvmfs_debuglog`

Data type: `Optional[Stdlib::Absolutepath]`

Create a debug log file at this location.

Default value: `undef`

##### <a name="-cvmfs--cvmfs_max_ttl"></a>`cvmfs_max_ttl`

Data type: `Optional[Integer]`

Max ttl.

Default value: `undef`

##### <a name="-cvmfs--cvmfs_version"></a>`cvmfs_version`

Data type: `String[1]`

Version of cvmfs to install.

Default value: `'present'`

##### <a name="-cvmfs--repo_base"></a>`repo_base`

Data type: `Stdlib::Httpurl`

URL containting stable, testing and config apt or yum repositories. Default in hiera data.

##### <a name="-cvmfs--repo_includepkgs"></a>`repo_includepkgs`

Data type: `Optional[Variant[Enum['absent'], Array[String[1]]]]`

Specify an includepkgs to the yum repos to ignore other packages.

##### <a name="-cvmfs--repo_priority"></a>`repo_priority`

Data type: `Integer`

Yum priority of repositories

Default value: `80`

##### <a name="-cvmfs--repo_proxy"></a>`repo_proxy`

Data type: `Optional[Stdlib::Httpurl]`

http proxy for cvmfs yum package repository

Default value: `undef`

##### <a name="-cvmfs--repo_config_enabled"></a>`repo_config_enabled`

Data type: `Boolean`

Should the config yum repository be enabled

Default value: `false`

##### <a name="-cvmfs--repo_testing_enabled"></a>`repo_testing_enabled`

Data type: `Boolean`

Should the testing repository be enabled.

Default value: `false`

##### <a name="-cvmfs--repo_gpgcheck"></a>`repo_gpgcheck`

Data type: `Boolean`

set to false to disable GPG checking

Default value: `true`

##### <a name="-cvmfs--repo_gpgkey"></a>`repo_gpgkey`

Data type: `Stdlib::Httpurl`

Set a custom GPG key for yum repos. Default in hiera data.

##### <a name="-cvmfs--repo_manage"></a>`repo_manage`

Data type: `Boolean`

Set to false to disable yum or apt repositories management.

Default value: `true`

##### <a name="-cvmfs--cvmfs_use_geoapi"></a>`cvmfs_use_geoapi`

Data type: `Optional[Enum['yes','no']]`

Enable geoapi to find suitable proxies.

Default value: `undef`

##### <a name="-cvmfs--cvmfs_repositories"></a>`cvmfs_repositories`

Data type: `Optional[String[1]]`

If undef `CVMFS_REPOSITORIES` in `default.local` will be populated
automatically from what is explicitly mounted with `cvmfs::mount`. If this is
specified then`CVMFS_REPOSITORIES` list in `default.local` will be exactly managed with this variable.
e.g `cvmfs-config.cern.ch,atlas.cern.ch`

Default value: `undef`

##### <a name="-cvmfs--cvmfs_hash"></a>`cvmfs_hash`

Data type: `Hash`

Rather than using cvmfs::mount defined type a hash of mounts can be sepecfied.

Default value: `{}`

##### <a name="-cvmfs--cvmfs_env_variables"></a>`cvmfs_env_variables`

Data type: `Hash`

`$cvmfs_env_variables = {'CMS_LOCAL_SITE' => '<path to siteconf>'`
 will produce `export CMS_LOCAL_SITE=<path to siteconf>`in the default.local file.

Default value: `{}`

##### <a name="-cvmfs--default_cvmfs_partsize"></a>`default_cvmfs_partsize`

Data type: `Integer`



Default value: `10000`

##### <a name="-cvmfs--cvmfs_domain_hash"></a>`cvmfs_domain_hash`

Data type: `Hash`

Specify of a hash `cvmfs::domain` types.

Default value: `{}`

##### <a name="-cvmfs--cvmfs_instrument_fuse"></a>`cvmfs_instrument_fuse`

Data type: `Boolean`

Instrument Fuse

Default value: `false`

##### <a name="-cvmfs--cvmfs_repo_list"></a>`cvmfs_repo_list`

Data type: `Boolean`

Specify exactly the REPO_LIST in `defaults.local` overriding auto population.

Default value: `true`

##### <a name="-cvmfs--cvmfs_alien_cache"></a>`cvmfs_alien_cache`

Data type: `Optional[String]`

Use an alien cache

Default value: `undef`

##### <a name="-cvmfs--cvmfs_shared_cache"></a>`cvmfs_shared_cache`

Data type: `Optional[Enum['yes','no']]`

Enable a shared cache

Default value: `undef`

##### <a name="-cvmfs--cvmfs_fsck"></a>`cvmfs_fsck`

Data type: `Boolean`

Ensure the cvmfs::fsck class is included.

Default value: `false`

##### <a name="-cvmfs--cvmfs_fsck_options"></a>`cvmfs_fsck_options`

Data type: `Optional[String]`

Any extra options for cvmfs fsck

Default value: `undef`

##### <a name="-cvmfs--cvmfs_fsck_onreboot"></a>`cvmfs_fsck_onreboot`

Data type: `Boolean`

Should fsck be run after every reboot

Default value: `false`

##### <a name="-cvmfs--fuse3"></a>`fuse3`

Data type: `Optional[Boolean]`

Install or disable fuse3 variant of cvmfs, if left `undef` no change will be made. Note that changing
this value when CvmFS mounts are active may well destroy those mounts.
Not availabe on Ubuntu 18.04.

Default value: `undef`

##### <a name="-cvmfs--cvmfs_cache_symlinks"></a>`cvmfs_cache_symlinks`

Data type: `Optional[Enum['yes','no']]`

If set to yes, enables symlink caching in the kernel.

Default value: `undef`

##### <a name="-cvmfs--cvmfs_streaming_cache"></a>`cvmfs_streaming_cache`

Data type: `Optional[Enum['yes','no']]`

If set to yes, use a download manager to download regular files on read.

Default value: `undef`

##### <a name="-cvmfs--cvmfs_statfs_cache_timeout"></a>`cvmfs_statfs_cache_timeout`

Data type: `Optional[Integer[1]]`

Caching time of statfs() in seconds (no caching by default).

Default value: `undef`

##### <a name="-cvmfs--cvmfs_world_readable"></a>`cvmfs_world_readable`

Data type: `Optional[Enum['yes','no']]`

Override posix read permissions to make files in repository globally readable

Default value: `undef`

##### <a name="-cvmfs--cvmfs_cpu_affinity"></a>`cvmfs_cpu_affinity`

Data type: `Optional[Array[Integer[0],1]]`

Set CPU affinity for all cvmfs components.

Default value: `undef`

##### <a name="-cvmfs--cvmfs_xattr_privileged_gids"></a>`cvmfs_xattr_privileged_gids`

Data type: `Optional[Array[Integer[1],1]]`

group IDs that are allowed to access the extended attributes by `$cvmfs_xattr_protected_xattrs`.

Default value: `undef`

##### <a name="-cvmfs--cvmfs_xattr_protected_xattrs"></a>`cvmfs_xattr_protected_xattrs`

Data type: `Optional[Array[String[1],1]]`

List of extended attributes (full name, e.g. user.fqrn) that are only accessible by root and the group IDs listed by `$cvmfs_xattr_privileged_gids`.

Default value: `undef`

##### <a name="-cvmfs--cvmfs_cache_refcount"></a>`cvmfs_cache_refcount`

Data type: `Optional[Enum['yes','no']]`

If set to yes, deduplicate open file descriptors by refcounting.

Default value: `undef`

##### <a name="-cvmfs--cvmfs_yum"></a>`cvmfs_yum`

Data type: `Optional[Stdlib::Httpurl]`

Deprecated, use repo_base

Default value: `undef`

##### <a name="-cvmfs--cvmfs_yum_priority"></a>`cvmfs_yum_priority`

Data type: `Optional[Integer]`

Deprecated, use repo_priority

Default value: `undef`

##### <a name="-cvmfs--cvmfs_yum_proxy"></a>`cvmfs_yum_proxy`

Data type: `Optional[Stdlib::Httpurl]`

Deprecated, user repo_proxy

Default value: `undef`

##### <a name="-cvmfs--cvmfs_yum_config"></a>`cvmfs_yum_config`

Data type: `Optional[Stdlib::Httpurl]`

Deprecated, use repo_base

Default value: `undef`

##### <a name="-cvmfs--cvmfs_yum_config_enabled"></a>`cvmfs_yum_config_enabled`

Data type: `Optional[Integer[0,1]]`

Deprecated, user repo_config_enabled

Default value: `undef`

##### <a name="-cvmfs--cvmfs_yum_testing"></a>`cvmfs_yum_testing`

Data type: `Optional[Stdlib::Httpurl]`

Deprecated, use repo_base

Default value: `undef`

##### <a name="-cvmfs--cvmfs_yum_testing_enabled"></a>`cvmfs_yum_testing_enabled`

Data type: `Optional[Integer[0,1]]`

Deprecated, use repo_testing_enabled

Default value: `undef`

##### <a name="-cvmfs--cvmfs_yum_gpgcheck"></a>`cvmfs_yum_gpgcheck`

Data type: `Optional[Integer[0,1]]`

Deprecated, use repo_gpgcheck

Default value: `undef`

##### <a name="-cvmfs--cvmfs_yum_gpgkey"></a>`cvmfs_yum_gpgkey`

Data type: `Optional[Variant[Stdlib::Filesource,Stdlib::Httpurl]]`

Deprecated, use repo_gpgkey

Default value: `undef`

##### <a name="-cvmfs--cvmfs_yum_manage_repo"></a>`cvmfs_yum_manage_repo`

Data type: `Optional[Boolean]`

Deprecated, use repo_manage

Default value: `undef`

##### <a name="-cvmfs--cvmfs_yum_includepkgs"></a>`cvmfs_yum_includepkgs`

Data type: `Optional[Variant[Enum['absent'], Array[String]]]`

Deprecated, use repo_includepkgs

Default value: `undef`

## Defined types

### <a name="cvmfs--domain"></a>`cvmfs::domain`

Configure a a domain of cvmfs repositories

#### Examples

##### Add the example.org domain

```puppet
cvmfs::domain{'example.org':
  cvmfs_server_url = 'http://example.org/cvmfs/@fqrn@',
}
```

#### Parameters

The following parameters are available in the `cvmfs::domain` defined type:

* [`domain`](#-cvmfs--domain--domain)
* [`cvmfs_quota_limit`](#-cvmfs--domain--cvmfs_quota_limit)
* [`cvmfs_server_url`](#-cvmfs--domain--cvmfs_server_url)
* [`cvmfs_http_proxy`](#-cvmfs--domain--cvmfs_http_proxy)
* [`cvmfs_timeout`](#-cvmfs--domain--cvmfs_timeout)
* [`cvmfs_timeout_direct`](#-cvmfs--domain--cvmfs_timeout_direct)
* [`cvmfs_nfiles`](#-cvmfs--domain--cvmfs_nfiles)
* [`cvmfs_max_ttl`](#-cvmfs--domain--cvmfs_max_ttl)
* [`cvmfs_env_variables`](#-cvmfs--domain--cvmfs_env_variables)
* [`cvmfs_use_geoapi`](#-cvmfs--domain--cvmfs_use_geoapi)
* [`cvmfs_follow_redirects`](#-cvmfs--domain--cvmfs_follow_redirects)
* [`cvmfs_external_fallback_proxy`](#-cvmfs--domain--cvmfs_external_fallback_proxy)
* [`cvmfs_external_http_proxy`](#-cvmfs--domain--cvmfs_external_http_proxy)
* [`cvmfs_external_timeout`](#-cvmfs--domain--cvmfs_external_timeout)
* [`cvmfs_external_timeout_direct`](#-cvmfs--domain--cvmfs_external_timeout_direct)
* [`cvmfs_external_url`](#-cvmfs--domain--cvmfs_external_url)
* [`cvmfs_public_key`](#-cvmfs--domain--cvmfs_public_key)
* [`cvmfs_keys_dir`](#-cvmfs--domain--cvmfs_keys_dir)

##### <a name="-cvmfs--domain--domain"></a>`domain`

Data type: `Stdlib::Fqdn`

The domain of CvmFS repositories to mount

Default value: `$name`

##### <a name="-cvmfs--domain--cvmfs_quota_limit"></a>`cvmfs_quota_limit`

Data type: `Optional[Integer]`

Per mount quota limit, not relavent to shared cache. Sets cvmfs_quota_limit

Default value: `undef`

##### <a name="-cvmfs--domain--cvmfs_server_url"></a>`cvmfs_server_url`

Data type: `Optional[String[1]]`

Stratum 1 list, typically `;` delimited. Sets CVMFS_SERVER_URL parameter.

Default value: `undef`

##### <a name="-cvmfs--domain--cvmfs_http_proxy"></a>`cvmfs_http_proxy`

Data type: `Optional[String[1]]`

List of http proxies to use. Sets CVMFS_PROXY_LIST parameter.

Default value: `undef`

##### <a name="-cvmfs--domain--cvmfs_timeout"></a>`cvmfs_timeout`

Data type: `Optional[Integer]`

Sets CVMFS_HTTP_TIMEOUT parameter

Default value: `undef`

##### <a name="-cvmfs--domain--cvmfs_timeout_direct"></a>`cvmfs_timeout_direct`

Data type: `Optional[Integer]`

Sets CVMFS_HTTP_TIMEOUT_DIRECT

Default value: `undef`

##### <a name="-cvmfs--domain--cvmfs_nfiles"></a>`cvmfs_nfiles`

Data type: `Optional[Integer]`

Number of open files permitted on the OS. Sets CVMFS_NFILES

Default value: `undef`

##### <a name="-cvmfs--domain--cvmfs_max_ttl"></a>`cvmfs_max_ttl`

Data type: `Optional[Integer]`

Maximum effective TTL in seconds for DNS queries of proxy server names. Sets CVMFS_MAX_TTL

Default value: `undef`

##### <a name="-cvmfs--domain--cvmfs_env_variables"></a>`cvmfs_env_variables`

Data type: `Optional[Hash]`

Sets per repo environments variables for magic links.

Default value: `undef`

##### <a name="-cvmfs--domain--cvmfs_use_geoapi"></a>`cvmfs_use_geoapi`

Data type: `Optional[Stdlib::Yes_no]`

Set CVMFS_MAX_GEOAPI

Default value: `undef`

##### <a name="-cvmfs--domain--cvmfs_follow_redirects"></a>`cvmfs_follow_redirects`

Data type: `Optional[Stdlib::Yes_no]`

Sets CVMFS_FOLLOW_REDIRECTS.

Default value: `undef`

##### <a name="-cvmfs--domain--cvmfs_external_fallback_proxy"></a>`cvmfs_external_fallback_proxy`

Data type: `Optional[String]`

Sets CVMFS_EXTERNAL_FALLBACK_PROXY

Default value: `undef`

##### <a name="-cvmfs--domain--cvmfs_external_http_proxy"></a>`cvmfs_external_http_proxy`

Data type: `Optional[String]`

Sets CVMFS_EXTERNAL_HTTP_PROXY

Default value: `undef`

##### <a name="-cvmfs--domain--cvmfs_external_timeout"></a>`cvmfs_external_timeout`

Data type: `Optional[Integer]`

Sets CVMFS_EXTERNAL_TIMEOUT

Default value: `undef`

##### <a name="-cvmfs--domain--cvmfs_external_timeout_direct"></a>`cvmfs_external_timeout_direct`

Data type: `Optional[Integer]`

Sets CVMFS_EXTERNAL_TIMEOUT_DIRECT

Default value: `undef`

##### <a name="-cvmfs--domain--cvmfs_external_url"></a>`cvmfs_external_url`

Data type: `Optional[String]`

Sets CVMFS_EXTERNAL_URL

Default value: `undef`

##### <a name="-cvmfs--domain--cvmfs_public_key"></a>`cvmfs_public_key`

Data type: `Optional[String[1]]`

Specify repository signing key

Default value: `undef`

##### <a name="-cvmfs--domain--cvmfs_keys_dir"></a>`cvmfs_keys_dir`

Data type: `Optional[Stdlib::Absolutepath]`

Specify repository directory with signing keys

Default value: `undef`

### <a name="cvmfs--id_map"></a>`cvmfs::id_map`

Create a map file uid or gid mappings

#### Parameters

The following parameters are available in the `cvmfs::id_map` defined type:

* [`map`](#-cvmfs--id_map--map)
* [`location`](#-cvmfs--id_map--location)

##### <a name="-cvmfs--id_map--map"></a>`map`

Data type: `Hash[Variant[Integer,String], Integer, 1]`

Hash of `{from => to}` pairs

##### <a name="-cvmfs--id_map--location"></a>`location`

Data type: `Stdlib::Absolutepath`

Path to write map to.

Default value: `$title`

### <a name="cvmfs--mount"></a>`cvmfs::mount`

Mount one cvmfs repository. Most parameters map as lower case
versions of the raw cvmfs parameters.

* **See also**
  * https://cvmfs.readthedocs.io/en/stable/apx-parameters.html
    * CVMFS configuration parameters

#### Examples

##### Trivial Mount

```puppet
cvmfs::mount{'files.example.org:
  cvmfs_server_url => 'http://web.exampple.org/cvmfs/files.example.org',
}
```

##### Mount with Environment Variables.

```puppet
cvmfs::mount{'foobar.example.org':
  cvmfs_env_variables => {
    'FOOT' => 'ball',
    'GOLF' => 'club',
  }
}
```

#### Parameters

The following parameters are available in the `cvmfs::mount` defined type:

* [`repo`](#-cvmfs--mount--repo)
* [`cvmfs_quota_limit`](#-cvmfs--mount--cvmfs_quota_limit)
* [`cvmfs_server_url`](#-cvmfs--mount--cvmfs_server_url)
* [`cvmfs_http_proxy`](#-cvmfs--mount--cvmfs_http_proxy)
* [`cvmfs_timeout`](#-cvmfs--mount--cvmfs_timeout)
* [`cvmfs_timeout_direct`](#-cvmfs--mount--cvmfs_timeout_direct)
* [`cvmfs_nfiles`](#-cvmfs--mount--cvmfs_nfiles)
* [`cvmfs_public_key`](#-cvmfs--mount--cvmfs_public_key)
* [`cvmfs_keys_dir`](#-cvmfs--mount--cvmfs_keys_dir)
* [`cvmfs_max_ttl`](#-cvmfs--mount--cvmfs_max_ttl)
* [`cvmfs_env_variables`](#-cvmfs--mount--cvmfs_env_variables)
* [`cvmfs_use_geoapi`](#-cvmfs--mount--cvmfs_use_geoapi)
* [`mount_method`](#-cvmfs--mount--mount_method)
* [`cvmfs_repo_list`](#-cvmfs--mount--cvmfs_repo_list)
* [`cvmfs_mount_rw`](#-cvmfs--mount--cvmfs_mount_rw)
* [`cvmfs_memcache_size`](#-cvmfs--mount--cvmfs_memcache_size)
* [`cvmfs_claim_ownership`](#-cvmfs--mount--cvmfs_claim_ownership)
* [`cvmfs_uid_map`](#-cvmfs--mount--cvmfs_uid_map)
* [`cvmfs_gid_map`](#-cvmfs--mount--cvmfs_gid_map)
* [`cvmfs_follow_redirects`](#-cvmfs--mount--cvmfs_follow_redirects)
* [`cvmfs_external_fallback_proxy`](#-cvmfs--mount--cvmfs_external_fallback_proxy)
* [`cvmfs_external_http_proxy`](#-cvmfs--mount--cvmfs_external_http_proxy)
* [`cvmfs_external_timeout`](#-cvmfs--mount--cvmfs_external_timeout)
* [`cvmfs_external_timeout_direct`](#-cvmfs--mount--cvmfs_external_timeout_direct)
* [`cvmfs_external_url`](#-cvmfs--mount--cvmfs_external_url)
* [`cvmfs_repository_tag`](#-cvmfs--mount--cvmfs_repository_tag)
* [`mount_options`](#-cvmfs--mount--mount_options)

##### <a name="-cvmfs--mount--repo"></a>`repo`

Data type: `Stdlib::Fqdn`

The fully qualified repository name to mount

Default value: `$name`

##### <a name="-cvmfs--mount--cvmfs_quota_limit"></a>`cvmfs_quota_limit`

Data type: `Optional[Integer]`

Per mount quota limit, not relavent to shared cache. Sets cvmfs_quota_limit

Default value: `undef`

##### <a name="-cvmfs--mount--cvmfs_server_url"></a>`cvmfs_server_url`

Data type: `Optional[String[1]]`

Stratum 1 list, typically `;` delimited. Sets CVMFS_SERVER_URL parameter.

Default value: `undef`

##### <a name="-cvmfs--mount--cvmfs_http_proxy"></a>`cvmfs_http_proxy`

Data type: `Optional[String[1]]`

List of http proxies to use. Sets CVMFS_PROXY_LIST parameter.

Default value: `undef`

##### <a name="-cvmfs--mount--cvmfs_timeout"></a>`cvmfs_timeout`

Data type: `Optional[Integer]`

Sets CVMFS_HTTP_TIMEOUT parameter

Default value: `undef`

##### <a name="-cvmfs--mount--cvmfs_timeout_direct"></a>`cvmfs_timeout_direct`

Data type: `Optional[Integer]`

Sets CVMFS_HTTP_TIMEOUT_DIRECT

Default value: `undef`

##### <a name="-cvmfs--mount--cvmfs_nfiles"></a>`cvmfs_nfiles`

Data type: `Optional[Integer]`

Number of open files permitted on the OS. Sets CVMFS_NFILES

Default value: `undef`

##### <a name="-cvmfs--mount--cvmfs_public_key"></a>`cvmfs_public_key`

Data type: `Optional[String[1]]`

Public key of repository, sets CVMFS_PUBLIC_KEYS

Default value: `undef`

##### <a name="-cvmfs--mount--cvmfs_keys_dir"></a>`cvmfs_keys_dir`

Data type: `Optional[Stdlib::Absolutepath]`

Directory with public keys for repository, sets CVMFS_KEYS_DIR

Default value: `undef`

##### <a name="-cvmfs--mount--cvmfs_max_ttl"></a>`cvmfs_max_ttl`

Data type: `Optional[Integer]`

Maximum effective TTL in seconds for DNS queries of proxy server names. Sets CVMFS_MAX_TTL

Default value: `undef`

##### <a name="-cvmfs--mount--cvmfs_env_variables"></a>`cvmfs_env_variables`

Data type: `Optional[Hash]`

Sets per repo environments variables for magic links.

Default value: `undef`

##### <a name="-cvmfs--mount--cvmfs_use_geoapi"></a>`cvmfs_use_geoapi`

Data type: `Optional[Stdlib::Yes_no]`

Set CVMFS_MAX_GEOAPI

Default value: `undef`

##### <a name="-cvmfs--mount--mount_method"></a>`mount_method`

Data type: `Enum['autofs','mount','none']`

Should the mount attempt be made with autofs or tranditional fstab mount. Do no use this.

Default value: `$cvmfs::mount_method`

##### <a name="-cvmfs--mount--cvmfs_repo_list"></a>`cvmfs_repo_list`

Data type: `Boolean`

If true the repository will added to the list of repositories maintained in `/etc/cvmfs/default.local`

Default value: `true`

##### <a name="-cvmfs--mount--cvmfs_mount_rw"></a>`cvmfs_mount_rw`

Data type: `Optional[Stdlib::Yes_no]`

sets CVMFS_MOUNT_RW

Default value: `undef`

##### <a name="-cvmfs--mount--cvmfs_memcache_size"></a>`cvmfs_memcache_size`

Data type: `Optional[Integer]`

Sets CVMFS_MEMCACHE_SIZE in Megabytes.

Default value: `undef`

##### <a name="-cvmfs--mount--cvmfs_claim_ownership"></a>`cvmfs_claim_ownership`

Data type: `Optional[Stdlib::Yes_no]`

Sets CVMFS_CLAIM_OWNERSHIP.

Default value: `undef`

##### <a name="-cvmfs--mount--cvmfs_uid_map"></a>`cvmfs_uid_map`

Data type: `Optional[Hash[Variant[Integer,String],Integer, 1]]`

Specify a UID map file path for this repository . Sets CVMFS_UID_MAP

Default value: `undef`

##### <a name="-cvmfs--mount--cvmfs_gid_map"></a>`cvmfs_gid_map`

Data type: `Optional[Hash[Variant[Integer,String],Integer, 1]]`

Specify a GID map file path for this repository . Sets CVMFS_GID_MAP

Default value: `undef`

##### <a name="-cvmfs--mount--cvmfs_follow_redirects"></a>`cvmfs_follow_redirects`

Data type: `Optional[Stdlib::Yes_no]`

Sets CVMFS_FOLLOW_REDIRECTS.

Default value: `undef`

##### <a name="-cvmfs--mount--cvmfs_external_fallback_proxy"></a>`cvmfs_external_fallback_proxy`

Data type: `Optional[String]`

Sets CVMFS_EXTERNAL_FALLBACK_PROXY

Default value: `undef`

##### <a name="-cvmfs--mount--cvmfs_external_http_proxy"></a>`cvmfs_external_http_proxy`

Data type: `Optional[String]`

Sets CVMFS_EXTERNAL_HTTP_PROXY

Default value: `undef`

##### <a name="-cvmfs--mount--cvmfs_external_timeout"></a>`cvmfs_external_timeout`

Data type: `Optional[Integer]`

Sets CVMFS_EXTERNAL_TIMEOUT

Default value: `undef`

##### <a name="-cvmfs--mount--cvmfs_external_timeout_direct"></a>`cvmfs_external_timeout_direct`

Data type: `Optional[Integer]`

Sets CVMFS_EXTERNAL_TIMEOUT_DIRECT

Default value: `undef`

##### <a name="-cvmfs--mount--cvmfs_external_url"></a>`cvmfs_external_url`

Data type: `Optional[String]`

Sets CVMFS_EXTERNAL_URL

Default value: `undef`

##### <a name="-cvmfs--mount--cvmfs_repository_tag"></a>`cvmfs_repository_tag`

Data type: `Optional[String[1]]`

Sets CVMFS_REPOSITORY_TAG

Default value: `undef`

##### <a name="-cvmfs--mount--mount_options"></a>`mount_options`

Data type: `String[1]`

Mount options to use for fstab style mounting.

Default value: `'defaults,_netdev,nodev'`

